#!/bin/bash

gpuid="${1}"

if [[ -z "${gpuid}" ]]; then
  echo "Specify gpuid"
  exit
fi

chmod +x ../scripts/*.sh

# Loop five training/test runs.
for seed in 3435 3436 3437 3438 3439; do
  model="model.seed${seed}.pt"
  if [[ -f "${model}" ]]; then
    echo "Skip: ${model} exists"
    continue
  fi

  # Train
  ../scripts/train.sh \
    ptb.train.txt \
    ptb.valid.txt \
    100 400 10 \
    "${seed}" \
    "${gpuid}"

  # Test
  ../scripts/test.sh \
    ptb.test.txt \
    "${seed}" \
    "${gpuid}"
done

# Compute mean and standard deviation.
tail -n2 model.seed*.pt.test.log \
  | grep nll \
  | cut -d ' ' -f 4- > tmpfile
python ../scripts/compute_mean_std.py tmpfile
rm -f tmpfile

# Uncomment below lines for evaluation using the importance sampling with 500 samples.
#for seed in 3435 3436 3437 3438 3439; do
#  ../scripts/test_iw.sh \
#    ptb.test.txt 500 \
#    "${seed}" \
#    "${gpuid}"
#done
#
#tail -n2 model.seed*.pt.test.iw500.log \
#  | grep nll \
#  | cut -d ' ' -f 4- > tmpfile
#echo "The results of importance sampling with 500 samples"
#python ../scripts/compute_mean_std.py tmpfile
#rm -f tmpfile
