# Copyright (C) 2019 Yahoo Japan Corporation

"""Compute mean and standard deviation."""
from __future__ import print_function
import sys
import numpy as np


def main():
    """Main workflow"""
    lines = []
    with open(sys.argv[1], "r") as f:
        for line in f:
            lines.append(line.strip())
    assert len(lines) == 5, "Need results from 5 runs"

    nlls, kls, ppls = [], [], []
    for line in lines:
        cols = line.split("|")
        assert len(cols) in {2, 3}, "Wrong format"
        for col in cols:
            toks = col.strip().split(" ")
            assert len(toks) == 3, "Wrong format"
            if toks[1] == "nll":
                nlls.append(float(toks[2]))
            elif toks[1] == "kl":
                kls.append(float(toks[2]))
            elif toks[1] == "ppl":
                ppls.append(float(toks[2]))
            else:
                raise RuntimeError("Wrong format")

    if kls:
        stats = {"NLL": np.array(nlls), "KL": np.array(kls), "PPL": np.array(ppls)}
    else:
        stats = {"NLL": np.array(nlls), "PPL": np.array(ppls)}

    for name, val in stats.items():
        print("{} = {:.1f} ({:.1f}) {}".format(name, np.mean(val), np.std(val), val))


if __name__ == "__main__":
    main()
